aboutsummaryrefslogtreecommitdiff
path: root/zephyr-upstream
diff options
context:
space:
mode:
authorPaul Sokolovsky <paul.sokolovsky@linaro.org>2020-12-14 18:02:32 +0300
committerPaul Sokolovsky <paul.sokolovsky@linaro.org>2020-12-14 18:02:32 +0300
commit86612aeb171079096c50b3aa5063490960df5057 (patch)
treeeaafc4404de2b43e0f4ada82933ac57839f1f525 /zephyr-upstream
parent0bef83e6a1d292e193d0fc6bfd064eac8bcf9513 (diff)
zephyr-upstream: 'sanitycheck' tool was renamed to 'twister'.
Change-Id: I590e2c41532d57b64f739861e7dc4a28a287f224 Signed-off-by: Paul Sokolovsky <paul.sokolovsky@linaro.org>
Diffstat (limited to 'zephyr-upstream')
-rwxr-xr-xzephyr-upstream/builders.sh14
1 files changed, 7 insertions, 7 deletions
diff --git a/zephyr-upstream/builders.sh b/zephyr-upstream/builders.sh
index 5c59cd69ab..9d93faa5b4 100755
--- a/zephyr-upstream/builders.sh
+++ b/zephyr-upstream/builders.sh
@@ -110,10 +110,10 @@ rm -rf ${OUTDIR}
echo ""
echo "########################################################################"
-echo " sanitycheck"
+echo " mass-build (twister)"
echo "########################################################################"
-time ${ZEPHYR_BASE}/scripts/sanitycheck \
+time ${ZEPHYR_BASE}/scripts/twister \
--platform ${PLATFORM} \
--inline-logs \
--build-only \
@@ -121,14 +121,14 @@ time ${ZEPHYR_BASE}/scripts/sanitycheck \
--enable-slow \
-x=USE_CCACHE=${USE_CCACHE} \
--jobs 2 \
- ${SANITYCHECK_EXTRA}
+ ${TWISTER_EXTRA}
-# Put sanitycheck report where rsync below will pick it up.
-cp ${OUTDIR}/sanitycheck.csv ${OUTDIR}/${PLATFORM}/
+# Put report where rsync below will pick it up.
+cp ${OUTDIR}/twister.csv ${OUTDIR}/${PLATFORM}/
cd ${ZEPHYR_BASE}
# OUTDIR is already per-platform, but it may get contaminated with unrelated
# builds e.g. due to bugs in sanitycheck script. It however stores builds in
# per-platform named subdirs under its --outdir (${OUTDIR} in our case), so
# we use ${OUTDIR}/${PLATFORM} paths below.
find ${OUTDIR}/${PLATFORM} -type f -name '.config' -exec rename 's/.config/zephyr.config/' {} +
@@ -136,7 +136,7 @@ rsync -avm \
--include=zephyr.bin \
--include=zephyr.config \
--include=zephyr.elf \
- --include=sanitycheck.csv \
+ --include='twister.*' \
--include='*/' \
--exclude='*' \
${OUTDIR}/${PLATFORM} ${WORKSPACE}/out/
@@ -121,14 +121,14 @@ time ${ZEPHYR_BASE}/scripts/sanitycheck \
cd ${ZEPHYR_BASE}
# OUTDIR is already per-platform, but it may get contaminated with unrelated
-# builds e.g. due to bugs in sanitycheck script. It however stores builds in
+# builds e.g. due to bugs in twister script. It however stores builds in
# per-platform named subdirs under its --outdir (${OUTDIR} in our case), so
# we use ${OUTDIR}/${PLATFORM} paths below.